@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab-grouper.c,v 1.5 2005/01/13 16:15:50 chpe Exp $
+ *  $Id: ephy-tab-grouper.c,v 1.6 2005/01/28 22:30:36 chpe Exp $
  */
 
 #include "config.h"
@@ -143,7 +143,7 @@ ephy_tab_grouper_init (EphyTabGrouper *grouper)
 {
 	grouper->priv = EPHY_TAB_GROUPER_GET_PRIVATE (grouper);
 
-	LOG ("EphyTabGrouper initialised")
+	LOG ("EphyTabGrouper initialised");
 }
 
 static void
@@ -156,7 +156,7 @@ ephy_tab_grouper_finalize (GObject *object)
 		(grouper->priv->notebook, G_SIGNAL_MATCH_DATA,
 		 0, 0, NULL, NULL, grouper);
 
-	LOG ("EphyTabGrouper finalised")
+	LOG ("EphyTabGrouper finalised");
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
